@@ -46,6 +46,9 @@ HK_UPDATE_COALESCE_SECONDS = 2.00
 # How long to wait before processing a manual update request
 MANUAL_UPDATE_COALESCE_SECONDS = 0.75
 
+# How long to wait to query the lock after an operation to make sure its not jammed
+POST_OPERATION_SYNC_TIME = 10.00
+
 # How long to wait if we get an update storm from the lock
 UPDATE_IN_PROGRESS_DEFER_SECONDS = 29.50
 
@@ -264,6 +267,7 @@ class PushLock:
             self._ble_device,
             self._lock_key,
             self._lock_key_index,
+            self._lock_info,
             self.name,
             cached_services=self._cached_services,
         )
@@ -305,6 +309,7 @@ class PushLock:
             raise
         self._callback_state(LockState(LockStatus.LOCKED, self.door_status))
         await self._cancel_any_update()
+        self._schedule_update(POST_OPERATION_SYNC_TIME)
         _LOGGER.debug("%s: Finished lock", self.name)
 
     @cancelable_operation
@@ -325,6 +330,7 @@ class PushLock:
             raise
         self._callback_state(LockState(LockStatus.UNLOCKED, self.door_status))
         await self._cancel_any_update()
+        self._schedule_update(POST_OPERATION_SYNC_TIME)
         _LOGGER.debug("%s: Finished unlock", self.name)
 
     async def update(self) -> None:
